@@ -1,2 +1,2 @@
-from .progress import ProgressBar
+from .progress import *
 from ._version import __version__
