@@ -13,7 +13,7 @@ from numba import types
 from numba.core import cgutils
 from numba.core.boxing import unbox_array
 
-__all__ = ['ProgressBar']
+__all__ = ['ProgressBar', 'ProgressBarType']
 
 def is_notebook():
     """Determine if we're running within an IPython kernel
@@ -121,23 +121,24 @@ class ProgressBar(object):
 
 # Numba Native Implementation for the ProgressBar Class
 
-class ProgressBarType(types.Type):
+class ProgressBarTypeImpl(types.Type):
     def __init__(self):
         super().__init__(name='ProgressBar')
 
 
-progressbar_type = ProgressBarType()
+# This is the numba type representation of the ProgressBar class to be used in signatures
+ProgressBarType = ProgressBarTypeImpl()
 
 
 @typeof_impl.register(ProgressBar)
 def typeof_index(val, c):
-    return progressbar_type
+    return ProgressBarType
 
 
-as_numba_type.register(ProgressBar, progressbar_type)
+as_numba_type.register(ProgressBar, ProgressBarType)
 
 
-@register_model(ProgressBarType)
+@register_model(ProgressBarTypeImpl)
 class ProgressBarModel(models.StructModel):
     def __init__(self, dmm, fe_type):
         members = [
@@ -147,17 +148,17 @@ class ProgressBarModel(models.StructModel):
 
 
 # make the hook attribute accessible
-make_attribute_wrapper(ProgressBarType, 'hook', 'hook')
+make_attribute_wrapper(ProgressBarTypeImpl, 'hook', 'hook')
 
 
-@overload_attribute(ProgressBarType, 'value')
+@overload_attribute(ProgressBarTypeImpl, 'value')
 def get_value(progress_bar):
     def getter(progress_bar):
         return progress_bar.hook[0]
     return getter
 
 
-@unbox(ProgressBarType)
+@unbox(ProgressBarTypeImpl)
 def unbox_progressbar(typ, obj, c):
     """
     Convert a ProgressBar to it's native representation (proxy object)
@@ -170,18 +171,18 @@ def unbox_progressbar(typ, obj, c):
     return NativeValue(progress_bar._getvalue(), is_error=is_error)
 
 
-@box(ProgressBarType)
+@box(ProgressBarTypeImpl)
 def box_progressbar(typ, val, c):
     raise TypeError("Native representation of ProgressBar cannot be converted back to a python object "
                     "as it contains internal python state.")
 
 
-@overload_method(ProgressBarType, "update", jit_options={"nogil": True})
+@overload_method(ProgressBarTypeImpl, "update", jit_options={"nogil": True})
 def _ol_update(self, n=1):
     """
     Numpy implementation of the update method.
     """
-    if isinstance(self, ProgressBarType):
+    if isinstance(self, ProgressBarTypeImpl):
         def _update_impl(self, n=1):
             atomic_add(self.hook, 0, n)
         return _update_impl
